%Translate = split('\n',<<END_OF_TRANSLATION);
Unknown Error (no error text)

Could not create %s

Showing revision %s

Revision %s not available

showing current revision instead

Updates since %s

Updates in the last %s day

Updates in the last %s days

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Could not open old %s log file

for %s only

%s day

%s days

List new changes starting from

No updates since %s

Page generated %s

(edit)

(diff)

changes

History of %s

Compare

(logged)

Revision %s

Edit

by

Preferences

Random Page

Upload

ID %s

from %s

[Home]

redirected from %s

Edit revision %s of this page

Edit text of this page

This page is read-only

View other revisions

View current revision

Search MetaWiki

Last edited

Edited

by %s

Warning

Database is stored in temporary directory %s

Config file error:

Administration

Unlock page

Lock page

Delete this page

Edit Banned List

Run Maintenance

Edit/Rename pages

Unlock site

Lock site

Search:

Go!

Your browser should go to the %s page.

If it does not, click %s to continue.

Thanks for editing...

Thank you for editing %s.

Link to another page...

Follow the %s link to continue.

Local rule error:

major diff

minor diff

author diff

major

minor

author

(The revisions are identical or unavailable.)

no other diffs

No diff available.

current revision

revision %s

Difference (from revision %1 to %2)

No diff available--this is the first %s revision.

Difference (from prior %s revision)

Changed:

Removed:

Added:

Describe the new page here.

Bad page version (or corrupt page).

cant write %s

Page name is too long: %s

Page name may not contain space characters: %s

Too many / characters in page %s

Invalid Page %s (subpage without main page)

Invalid Page %s (missing subpage name)

Invalid Page %s (/ not allowed)

Invalid Page %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

can not make %s

Can not open %s

Invalid action parameter %s

Invalid URL.

Editing Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

Editing not allowed: %s is read-only.

Editing %s

Editing revision %s of 

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Edit Conflict!

(This is a new conflict)

Someone saved this page after you started editing.

The top textbox contains the saved text.

Only the text in the top textbox will be saved.

Scroll down to see your edited text.

Last save time:

Current time is:

Summary:

This change is a minor edit.

Send email notification that %s has been changed.

Save

Your user name is

Visit %s to set your user name.

Preview

This is the text you submitted:

Preview:

NOTE: This preview shows the revision of the other author.

Preview only, not yet saved

Editing Preferences

User Information:

Your User ID number: %s

UserName:

(blank to remove, or valid page name)

Set Password:

(blank to remove password)

Passwords allow sharing preferences between multiple systems.

Passwords are completely optional.

Administrator Password:

(Administrator passwords are used for special maintenance.)

Include this address in the site email list.

(Uncheck the box to remove the address.)

Email Address:

Default days to display:

Most recent changes on top

Show all changes (not just most recent)

Hide minor edits

Show minor edits

Show only minor edits

Minor edit display:

Use "changes" as link to history

Differences:

Show (diff) links on %s

Show differences on all pages

No differences on %s

Major

Minor

Author

Default difference type:

Misc:

Server time:

Time Zone offset (hours):

Use 100% wide edit area (if supported)

Edit area rows:

columns:

Show link bar on top

Add "Random Page" link to link bar

StyleSheet URL:

Saving Preferences

Invalid UserID %s, preferences not saved.

(Preferences require cookies, but no cookie was sent.)

UserName removed.

Invalid UserName %s: not saved.

UserName must be 50 characters or less. (not saved)

UserName %s saved.

Password removed.

Password changed.

Administrator password removed.

Administrator password changed.

User has administrative abilities.

User has editor abilities.

User does not have administrative abilities.

(Password does not match administrative password(s).)

Local time:

StyleSheet URL removed.

StyleSheet setting saved.

Preferences saved.

Could not read from %s:

Could not get mail lock

Could not append to %s:

Could not overwrite %s:

Index of all pages

Login

User ID number:

Password:

Login Results

Login for user ID %s complete.

Login for user ID %s failed.

Could not get user-ID lock

Search for: %s

Backlinks for: %s

%s pages found:

Full Link List

Editing not allowed for %s.

SampleUndefinedPage

Sample_Undefined_Page

%s cannot be defined.

Could not get editing lock

Normal Unlock.

Removing edit lock

This operation may take several seconds...

Forced Unlock.

%s log error:

can not write diff_log

(done)

(deleted)

(replaced)

Maintenance on all pages

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Could not get maintain-lock

Maintenance done at %s

Processing rename/delete commands:

Could not get lock for RC maintenance

Maintaining RC log

RC maintenance done.

RC maintenance not done.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

Set global edit lock

Remove global edit lock

Edit lock created.

Edit lock removed.

Set page edit lock

Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Editing Banned list

Updating Banned list

Empty banned list or error.

Resubmit with at least one space character to remove.

Removed banned list

Updated banned list

Editing Links

UpdateLinksList could not get main lock

Updating Links

Empty command list or error.

Finished command list.

Could not open %s log file:

Error was:

Delete-Page: page %1 is invalid, error is: %2

Rename-Text: old page %1 is invalid, error is: %2

Rename-Text: new page %1 is invalid, error is: %2

Rename: old page %1 is invalid, error is: %2

Rename: new page %1 is invalid, error is: %2

Rename: new page %s already exists--not renamed.

Rename: old page %s does not exist--nothing done.

Displaying Wiki Version

Delete %s

Confirm deletion of %s by following this link:

Confirm Delete

%s can not be deleted.

%s can not be deleted because it is locked.

%s has been deleted.

File Upload Page

The current upload size limit is %s.

Change the %s variable to increase this limit.

File to Upload:

Upload Finished

The wiki link to your file is:

Could not open file %s

Convert wiki DB

You must change the %s option before converting the wiki DB.

Wiki DB locked for conversion.

Converting Wiki DB...

Finished converting wiki DB.

Remove file %s to unlock wiki for editing.

Trim wiki users

Removed %s files.

Recommended $StartUID setting is %s.

END_OF_TRANSLATION
